@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.7
+#!/usr/local/bin/python3.7
 __version__ = '2.2'
 __mod__ = 'hp-uiscan'
 __title__ = 'Scan Utility'
@@ -22,7 +22,9 @@ except ImportError as e:
 
 
 
-mod = module.Module(__mod__, __title__, __version__, __doc__, None, (INTERACTIVE_MODE,))
+#mod = module.Module(__mod__, __title__, __version__, __doc__, None, (INTERACTIVE_MODE,))
+mod = module.Module(__mod__, __title__, __version__, __doc__, None, (GUI_MODE,), (UI_TOOLKIT_QT4, UI_TOOLKIT_QT5))
+mod.setUsage(module.USAGE_FLAG_NONE, extra_options=None, see_also_list = ['hp-scan'])
 
 
 
